pub fn validate_timeout(timeout_ms: u32) -> Result<u32, SecurityError>Expand description
Validate a timeout value, returning an error if it exceeds the maximum allowed.
pub fn validate_timeout(timeout_ms: u32) -> Result<u32, SecurityError>Validate a timeout value, returning an error if it exceeds the maximum allowed.